#!/bin/sh

#=============================================================================
# APM Alert Email Script
#
# This script will construct an email body and send an email message based
# on information contained in the User Defined parameter in the APM
#
# Change history:
# 2012-01-10 Created by 
# 2012-12-11 Modified by 
# 2013-06-20 Further refined by 
#
#==============================================================================
#

	# Define the text body file with the system PID ($$) so calls won't cross over.
OUTPUT="/wilyMom/alerts/alert.$$.output"

LOG="/wilyMom/alerts/email.log"

	# Since there are more than 9 parameters, shifting the values to get them all
userdefined=$1
	shift
texttoshell=$1
	shift
emname=$1
	shift
emhost=$1
	shift
emip=$1
	shift
alertname=$1
	shift
alertstatus=$1
	shift
alerttime=$1
	shift
agentnames=$1
	shift
metricnames=$1
	shift
previousalertstate=$1
	shift
hasalertstatechanged=$1
	shift
thresholdvalue=$1

	# Set environment
emhost=`echo "$emhost"|sed s/\"//g`
if [ $emhost == "<PRODUCTION_MOM_HOST>" ]; then
	environment="Production"
else
	environment="Non-Production"
fi

	# Variables for creating a dynamic subject line for the email
alertstat=ERROR

	# Parse of userdefined parameter
userdefined=`echo "$userdefined"|sed s/\"//g`
email=`echo $userdefined |cut -d '+' -f1`
onCall=`echo $userdefined |cut -d '+' -f2`
instSet=`echo $userdefined |cut -d '+' -f3`
lmf=`echo $userdefined |cut -d '+' -f4`
action=`echo $userdefined |cut -d '+' -f5`

echo $email >> $LOG

	# Variable to show which server the alert is coming from
agentserver=`echo $agentnames |cut -d '|' -f2`

	# Remove quotes from alert status and previous status to compare as integers
	# sed command is in format sed s/{old}/{new}/g; using \ for special character
	# sed command will not error if quotes are not passed
alertstatus=`echo "$alertstatus"|sed s/\"//g`
previousalertstate=`echo "$previousalertstate"|sed s/\"//g`
if [ $previousalertstate == 3 ]; then
	previousalert=Danger
elif [ $previousalertstate == 2 ]; then
	previousalert=Caution
fi

	# Build the email body in a new file

	# Send GOOD message only if current alert status is 1 (Good), remove metric names on GOOD message
if [ $alertstatus -lt $previousalertstate ] && [ $alertstatus == 1 ]; then
	alertstat=GOOD
	metricnames=NONE
	subject="$environment - $previousalert"
	if [ -f /wilyMom/alerts/${instSet}.close ]; then				
	# Use customer-defined close message if provided, set environment, server name, and previous alert
		cat /wilyMom/alerts/${instSet}.close |sed -e s/::environment::/$environment/g -e s/::server::/$emhost/g -e s/::previousalert::/$previousalert/g >> $OUTPUT
	else
	# Use customer-defined close message if provided, set environment, server name, and previous alert
		cat /wilyMom/alerts/default.close |sed -e s/::environment::/$environment/g -e s/::server::/$emhost/g -e s/::previousalert::/$previousalert/g >> $OUTPUT
	fi
fi

	# Create proper alert message (Caution or Danger)
	# Caution message has 2 states, Caution - ERROR (for first offense) and Caution - GOOD (when returning from Danger)
	# sed expression removes alternate Caution message tagged by either GG (for GOOD message) or EE (for ERROR message)
if [ $alertstatus == 2 ]; then
	# Set Caution - ERROR message
	if [ $action == "caution" ]; then
		subject="$environment - Caution"
		if [ -f /wilyMom/alerts/${instSet}Caution.instructions ]; then		# Check for user-defined instructions
			cat /wilyMom/alerts/${instset}Caution.instructions |sed -e s/::environment::/$environment/g -e s/::server::/$emhost/g -e 's/EE//g' -e '/GG.*GG/d' >> $OUTPUT
		else
		# Default instructions are standard caution (SiteScope instructions)
			cat /wilyMom/alerts/defaultCaution.instructions |sed -e s/::environment::/$environment/g -e s/::server::/$emhost/g -e 's/EE//g' -e '/GG.*GG/d' >> $OUTPUT
		fi
	# Set Caution - GOOD message
	else
		alertstat=GOOD
		subject="$environment - Danger"
	        if [ -f /wilyMom/alerts/${instSet}.close ]; then                        # Use customer-defined close message if provided
			cat /wilyMom/alerts/${instset}Caution.instructions |sed -e '/EE.*EE/d' -e 's/GG//g' -e s/::environment::/$environment/g -e s/::server::/$emhost/g >> $OUTPUT
       		else
                	cat /wilyMom/alerts/defaultCaution.instructions |sed -e '/EE.*EE/d' -e 's/GG//g' -e s/::environment::/$environment/g -e s/::server::/$emhost/g >> $OUTPUT
        	fi

	fi

elif [ $alertstatus == 3 ]; then
	if [ $action == "caution" ]; then
		exit 0
	fi
	subject="$environment - Danger"
	if [ -f /wilyMom/alerts/${instSet}Danger.instructions ]; then			# Check for user-defined instruction file
		# Find and replace on call contact, environment, and server info
		cat /wilyMom/alerts/${instSet}Danger.instructions |sed -e s/::who2contact::/$onCall/g -e s/::environment::/$environment/g -e s/::server::/$emhost/g >> $OUTPUT
	else
		# Find and replace on call contact, environment, and server info
		# Default instructions are standard 10 minute (SiteScope instructions)
		cat /wilyMom/alerts/defaultDanger.instructions |sed -e s/::who2contact::/$onCall/g -e s/::environment::/$environment/g -e s/::server::/$emhost/g >> $OUTPUT
	fi
fi

	# Format the text to be a little more readable
	# In summary alerts put each of the included alerts on new lines
text=`echo "$texttoshell"|sed -e "s/         /\n/g"`

	# In basic alerts put the threshold and actual value on a new line.
text=`echo "$text"|sed -e "s/: /\n\n    /g"`

	# appends the parameters passed in from Wily
echo " " >> $OUTPUT
echo " " >> $OUTPUT
echo Parameters:  >> $OUTPUT
echo " " >> $OUTPUT
echo "    Agent Server = $agentserver" >> $OUTPUT
echo " " >> $OUTPUT
echo "    Alert Time = $alerttime"  >> $OUTPUT
echo " " >> $OUTPUT
	
	# Send basic information alert
if [ $lmf = "l" ]; then
	mail -r APM_ALERT -s "$subject - $alertstat - $alertname" $email < $OUTPUT
fi

	# Add medium-level information
echo "    Alert Text = $text" >> $OUTPUT
echo " " >> $OUTPUT

	# Send mid-level information alert
if [ $lmf == "m" ]; then
	mail -r APM_ALERT -s "$subject - $alertstat - $alertname" $email < $OUTPUT
fi

	# Add full-level information
echo "    Current Alert Status = $alertstatus"  >> $OUTPUT
echo " " >> $OUTPUT
echo "    Previous Alert State = $previousalertstate"  >> $OUTPUT
echo " " >> $OUTPUT
echo "    Alert Name = $alertname"  >> $OUTPUT
echo "    Agent Names = $agentnames"  >> $OUTPUT
echo "    Offending Metric = $metricnames"  >> $OUTPUT
echo " " >> $OUTPUT

	# Send full information alert
if [ $lmf == "f" ]; then
	mail -r APM_ALERT -s "$subject - $alertstat - $alertname" $email < $OUTPUT
fi

	# removes the body text file
rm $OUTPUT
